@@ -176,7 +176,6 @@ static const char *fbSymbols[] = {
 };
 
 static const char *shadowSymbols[] = {
-    "shadowAlloc",
     "shadowInit",
     "shadowUpdatePackedWeak",
     "shadowUpdatePlanar4Weak",
@@ -789,11 +788,6 @@ VESAScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     if (pVesa->shadowFB && pScrn->bitsPerPixel == 4)
 	pScrn->bitsPerPixel = 8;
 
-    if (pVesa->shadowFB && (pVesa->shadowPtr =
-	shadowAlloc(pScrn->virtualX, pScrn->virtualY,
-		    pScrn->bitsPerPixel)) == NULL)
-	return (FALSE);
-
     /* save current video state */
     VESASaveRestore(pScrn, MODE_SAVE);
     pVesa->savedPal = VBESetGetPaletteData(pVesa->pVbe, FALSE, 0, 256,
@@ -838,24 +832,6 @@ VESAScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 		       "Unsupported Memory Model: %d", mode->MemoryModel);
 	    return (FALSE);
 	case 0x3:	/* Planar */
-	    if (pVesa->shadowFB) {
-	        if (pScrn->depth == 1) {
-		    if (!mfbScreenInit(pScreen,
-				      pVesa->shadowPtr,
-				      pScrn->virtualX, pScrn->virtualY,
-				      pScrn->xDpi, pScrn->yDpi,
-				      pScrn->displayWidth))
-		        return FALSE;
-		} else {
-		    if (!fbScreenInit(pScreen,
-				      pVesa->shadowPtr,
-				      pScrn->virtualX, pScrn->virtualY,
-				      pScrn->xDpi, pScrn->yDpi,
-				      pScrn->displayWidth, pScrn->bitsPerPixel))
-		    return (FALSE);
-		    init_picture = 1;
-		}
-	    } else {
 		switch (pScrn->bitsPerPixel) {
 		    case 1:
 			if (!xf1bppScreenInit(pScreen, pVesa->base,
@@ -880,7 +856,6 @@ VESAScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 			    return (FALSE);
 			break;
 		}
-	    }
 	    break;
 	case 0x4:	/* Packed pixel */
 	case 0x6:	/*  Direct Color */
@@ -890,7 +865,7 @@ VESAScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 		case 24:
 		case 32:
 		    if (!fbScreenInit(pScreen,
-			    pVesa->shadowFB ? pVesa->shadowPtr : pVesa->base,
+				       pVesa->base,
 				       pScrn->virtualX, pScrn->virtualY,
 				       pScrn->xDpi, pScrn->yDpi,
 				       pScrn->displayWidth, pScrn->bitsPerPixel))
@@ -1030,10 +1005,6 @@ VESACloseScreen(int scrnIndex, ScreenPtr pScreen)
 				 pVesa->savedPal, FALSE, TRUE);
 	VESAUnmapVidMem(pScrn);
     }
-    if (pVesa->shadowPtr) {
-	xfree(pVesa->shadowPtr);
-	pVesa->shadowPtr = NULL;
-    }
     if (pVesa->pDGAMode) {
 	xfree(pVesa->pDGAMode);
 	pVesa->pDGAMode = NULL;
@@ -1102,7 +1073,8 @@ VESASetMode(ScrnInfoPtr pScrn, DisplayModePtr pMode)
     if (data->data->XResolution != pScrn->displayWidth)
 	VBESetLogicalScanline(pVesa->pVbe, pScrn->displayWidth);
 
-    if (pScrn->bitsPerPixel == 8 && pVesa->vbeInfo->Capabilities[0] & 0x01)
+    if (pScrn->bitsPerPixel == 8 && pVesa->vbeInfo->Capabilities[0] & 0x01 &&
+        !(data->data->MemoryModel & 0x6 || data->data->MemoryModel & 0x7)) 
 	VBESetGetDACPaletteFormat(pVesa->pVbe, 8);
 
     pScrn->vtSema = TRUE;
